--- old/usr/src/lib/libm/common/m9x/scalblnf.c	2019-06-06 20:40:36.707770183 +0000
+++ new/usr/src/lib/libm/common/m9x/scalblnf.c	2019-06-06 20:40:36.729847865 +0000
@@ -22,6 +22,7 @@
 /*
  * Copyright 2011 Nexenta Systems, Inc.  All rights reserved.
  */
+
 /*
  * Copyright 2006 Sun Microsystems, Inc.  All rights reserved.
  * Use is subject to license terms.
@@ -30,9 +31,10 @@
 #pragma weak __scalblnf = scalblnf
 
 #include "libm.h"
-#include <float.h>		/* FLT_MAX, FLT_MIN */
+#include <float.h>			/* FLT_MAX, FLT_MIN */
 
 static const float twom25f = 2.98023223876953125e-8F;
+
 #if defined(__x86)
 static const float two23f = 8388608.0F;
 #else
@@ -40,34 +42,42 @@
  * v: a non-zero subnormal |x|; returns [-22, 0]
  */
 static int
-ilogbf_biased(unsigned v) {
+ilogbf_biased(unsigned v)
+{
 	int r = -22;
 
 	if (v & 0xffff0000)
 		r += 16, v >>= 16;
+
 	if (v & 0xff00)
 		r += 8, v >>= 8;
+
 	if (v & 0xf0)
 		r += 4, v >>= 4;
+
 	v <<= 1;
 	return (r + ((0xffffaa50 >> v) & 0x3));
 }
-#endif	/* defined(__x86) */
+#endif /* defined(__x86) */
 
 float
-scalblnf(float x, long n) {
-	int *px = (int *) &x, ix, k;
+scalblnf(float x, long n)
+{
+	int *px = (int *)&x, ix, k;
 
 	ix = *px & ~0x80000000;
 	k = ix >> 23;
+
 	if (k == 0xff)
 #if defined(FPADD_TRAPS_INCOMPLETE_ON_NAN)
 		return (ix > 0x7f800000 ? x * x : x);
 #else
 		return (x + x);
 #endif
+
 	if (ix == 0 || n == 0)
 		return (x);
+
 	if (k == 0) {
 #if defined(__x86)
 		x *= two23f;
@@ -77,15 +87,20 @@
 		*px = (*px & 0x80000000) | (ix << (-k + 1));
 #endif
 	}
-	k += (int) n;
+
+	k += (int)n;
+
 	if (n > 5000 || k > 0xfe)
 		return (FLT_MAX * copysignf(FLT_MAX, x));
+
 	if (n < -5000 || k <= -25)
 		return (FLT_MIN * copysignf(FLT_MIN, x));
+
 	if (k > 0) {
 		*px = (*px & ~0x7f800000) | (k << 23);
 		return (x);
 	}
+
 	k += 25;
 	*px = (*px & ~0x7f800000) | (k << 23);
 	return (x * twom25f);
